@@ -107,7 +107,6 @@
 #include <QtCharts/qlineseries.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -122,6 +121,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -209,16 +213,16 @@ extern SbkConverter **SbkPySide6_QtChartsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 0, // QList<QObject* >
-    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 1, // QList<QByteArray >
-    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 2, // QList<QAction* >
-    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 3, // QList<QLegendMarker* >
-    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 4, // QList<QGraphicsItem* >
-    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 5, // QList<QRectF >
-    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 6, // QList<QAbstractAxis* >
-    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 7, // QList<QAbstractSeries* >
-    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 8, // QList<qreal >
-    SBK_QTCHARTS_QLIST_INT_IDX                               = 9, // QList<int >
+    SBK_QTCHARTS_QLIST_INT_IDX                               = 0, // QList<int >
+    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 1, // QList<QObject* >
+    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 2, // QList<QByteArray >
+    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 3, // QList<QAction* >
+    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 4, // QList<QLegendMarker* >
+    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 5, // QList<QGraphicsItem* >
+    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 6, // QList<QRectF >
+    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 7, // QList<QAbstractAxis* >
+    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 8, // QList<QAbstractSeries* >
+    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 9, // QList<qreal >
     SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF >
     SBK_QTCHARTS_QPAIR_QREAL_QREAL_IDX                       = 11, // QPair<qreal,qreal >
     SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant >
