@@ -93,7 +93,6 @@
 #include <QtOpenGL/qopenglfunctions_4_4_core.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -108,6 +107,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -206,21 +210,22 @@ extern SbkConverter **SbkPySide6_QtOpenGLTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTOPENGL_QPAIR_INT_INT_IDX                           = 0, // QPair<int,int >
-    SBK_QTOPENGL_QPAIR_FLOAT_FLOAT_IDX                       = 1, // QPair<float,float >
-    SBK_QTOPENGL_QPAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 2, // QPair<QOpenGLTexture::Filter,QOpenGLTexture::Filter >
-    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 3, // QList<QSize >
-    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 4, // QList<unsigned int >
-    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 5, // QList<QObject* >
-    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 6, // QList<QByteArray >
-    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 7, // QList<uint64_t >
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 8, // QList<float >
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 9, // QList<QOpenGLShader* >
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 10, // QList<QOpenGLDebugMessage >
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 11, // QList<QVariant >
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 12, // QList<QString >
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 13, // QMap<QString,QVariant >
-    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 14
+    SBK_QTOPENGL_QLIST_INT_IDX                               = 0, // QList<int >
+    SBK_QTOPENGL_QPAIR_INT_INT_IDX                           = 1, // QPair<int,int >
+    SBK_QTOPENGL_QPAIR_FLOAT_FLOAT_IDX                       = 2, // QPair<float,float >
+    SBK_QTOPENGL_QPAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 3, // QPair<QOpenGLTexture::Filter,QOpenGLTexture::Filter >
+    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 4, // QList<QSize >
+    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 5, // QList<unsigned int >
+    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 6, // QList<QObject* >
+    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 7, // QList<QByteArray >
+    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 8, // QList<uint64_t >
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 9, // QList<float >
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 10, // QList<QOpenGLShader* >
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 11, // QList<QOpenGLDebugMessage >
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 12, // QList<QVariant >
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 13, // QList<QString >
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 14, // QMap<QString,QVariant >
+    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 15
 };
 // Macros for type check
 
