@@ -7,8 +7,8 @@ from textwrap import dedent
 __all__ = list("Qt" + body for body in
     "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.3.1"
-__version_info__ = (6, 3, 1, "", "")
+__version__ = "6.3.2"
+__version_info__ = (6, 3, 2, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -68,26 +68,6 @@ def _setupQtDirectories():
               file=sys.stderr)
         raise
 
-    #   Trigger signature initialization.
-    try:
-        # PYSIDE-829: Avoid non-existent attributes in compiled code (Nuitka).
-        # We now use an explicit function instead of touching a signature.
-        _init_pyside_extension()
-    except (AttributeError, NameError):
-        stars = 79 * "*"
-        fname = Shiboken.__file__
-        print(dedent(f'''\
-            {stars}
-            PySide6/__init__.py: The `signature` module was not initialized.
-            This libshiboken module was loaded from
-
-            "{fname}".
-
-            Please make sure that this is the real Shiboken binary and not just a folder.
-            {stars}
-            '''), file=sys.stderr)
-        raise
-
     if sys.platform == 'win32':
         # PATH has to contain the package directory, otherwise plugins
         # won't be able to find their required Qt libraries (e.g. the
